#
# spec file for package ghc-relude
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name relude
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.1.1
Release:        4.10
Summary:        Custom prelude from Kowainik
License:        MIT
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-utf8-string-devel
%if %{with tests}
BuildRequires:  ghc-Glob-devel
BuildRequires:  ghc-doctest-devel
BuildRequires:  ghc-hedgehog-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hedgehog-devel
%endif

%description
== Goals

* __Avoid all [partial
functions](https://www.reddit.com/r/haskell/comments/5n51u3/why_are_partial_functions_as_in_head_tail_bad/)__
(like 'head :: [a] -> a'). The types of partial functions lie about their
behavior and usage of such functions can lead to the unexpected bugs.
Though you can still use some unsafe functions from 'Relude.Unsafe' module, but
they are not exported by default.

* __Type-safety__. We like to make invalid states unrepresantable. And if it's
possible to express this concept through the types then we will do it.
/Example:/ ' whenNotNull :: Applicative f => [a] -> (NonEmpty a -> f ()) -> f
() '

* __Performance.__ Prefer 'Text' over
'[String](https://www.reddit.com/r/haskell/comments/29jw0s/whats_wrong_with_string/)',
use spaceleak-free functions (like our custom 'sum' and 'product').

* __Minimalism__ (low number of dependencies). We don't force users of 'relude'
to stick to some specific lens or text formatting or logging library.

* __Convenience__ (like lifted to 'MonadIO' functions, more reexports).
But we want to bring common types and functions (like 'containers' and
'bytestrng') into scope because they are used in almost every application
anyways.

* __Provide excellent documentation.__

1. Tutorial

2. Migration guide from 'Prelude'

3. Haddock with examples for (almost) every function (all examples are tested
with [`doctest`](http://hackage.haskell.org/package/doctest))

4. Documentation regarding [internal module
structure]((http://hackage.haskell.org/package/relude/docs/Relude.html))

5. 'relude'-specific [HLint](http://hackage.haskell.org/package/hlint) rules:
'[.hlint.yaml](https://github.com/kowainik/relude/blob/master/.hlint.yaml)'

* __User-friendliness.__ Ability to quickly migrate to 'relude' if you're
familiar with the common libraries like 'text' and 'containers'.

* __Exploration.__ Experiment with new ideas and proposals without introducing
breaking changes.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal
echo > Setup.hs 'import Distribution.Simple'
echo >>Setup.hs 'main = defaultMain'

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Tue Aug 14 2018 psimons@suse.com
- Update relude to version 0.1.1.
  0.1.1
  =====
  * [#44](https://github.com/kowainik/relude/issues/44)
    Implement parser deriviation from pretty-printers
* Sun Jul 29 2018 psimons@suse.com
- Add relude at version 0.1.0.
